# examples for pywpsrpc

Each root directory contains examples for corresponding module.


To run the demos, you should have installed the pywpsrpc package.

You also need to install the pyside2 to make the demo runs fine.